---
title: Recharge
description: Represents a command for an agent to recharge.
---

## Signature

```py
Recharge()
```

## Description

Represents a command for the agent to recharge its energy.  
This command is effective only when the agent is located on a cell of type `CHARGING_CELL`.  
If used elsewhere, the command will have no effect.

## Example

```py
if cell.is_charging_cell():
  agent.send(Recharge())
```
